Merge pull request #285 from aaronenyeshi/fix-ilogb-unreachable

Fix ilogb/ilogbf functions to return int
Bu işleme şunda yer alıyor:
Maneesh Gupta
2017-12-12 10:47:33 +05:30
işlemeyi yapan: GitHub
işleme 6293d3f887
2 değiştirilmiş dosya ile 4 ekleme ve 4 silme
+2 -2
Dosyayı Görüntüle
@@ -67,7 +67,7 @@ __device__ float fminf(float x, float y);
__device__ float fmodf(float x, float y);
__device__ float frexpf(float x, int* nptr);
__device__ float hypotf(float x, float y);
__device__ float ilogbf(float x);
__device__ int ilogbf(float x);
__device__ int isfinite(float a);
__device__ unsigned isinf(float a);
__device__ unsigned isnan(float a);
@@ -153,7 +153,7 @@ __device__ double fmin(double x, double y);
__device__ double fmod(double x, double y);
__device__ double frexp(double x, int *nptr);
__device__ double hypot(double x, double y);
__device__ double ilogb(double x);
__device__ int ilogb(double x);
__device__ int isfinite(double x);
__device__ unsigned isinf(double x);
__device__ unsigned isnan(double x);